@@ -11,11 +11,14 @@ export PATH="${PATH}:${root}/.ci"
 pushd "${root}" > "${output}"
 
 if [ "${repo_name}" = "vagrant" ]; then
-    remote_repository="hashicorp/vagrant-blackbox"
+    remote_repository="hashicorp/vagrant-acceptance"
 else
   fail "This repository is not configured to sync vagrant to mirror repository"
 fi
 
+wrap git config pull.rebase false \
+     "Failed to configure git pull strategy"
+
 echo "Adding remote mirror repository '${remote_repository}'..."
 wrap git remote add mirror "https://${HASHIBOT_USERNAME}:${HASHIBOT_TOKEN}@github.com/${remote_repository}" \
      "Failed to add mirror '${remote_repository}' for sync"
