@@ -356,6 +356,10 @@ module Vagrant
       error_key(:darwin_mount_failed)
     end
 
+    class DarwinVersionFailed < VagrantError
+      error_key(:darwin_version_failed)
+    end
+
     class DestroyRequiresForce < VagrantError
       error_key(:destroy_requires_force)
     end
@@ -592,6 +596,10 @@ module Vagrant
       error_key(:requires_directory, "vagrant.actions.general.package")
     end
 
+    class PackageInvalidInfo < VagrantError
+      error_key(:package_invalid_info)
+    end
+
     class PowerShellNotFound < VagrantError
       error_key(:powershell_not_found)
     end
@@ -636,6 +644,18 @@ module Vagrant
       error_key(:provisioner_winrm_unsupported)
     end
 
+    class PluginNeedsDeveloperTools < VagrantError
+      error_key(:plugin_needs_developer_tools)
+    end
+
+    class PluginMissingLibrary < VagrantError
+      error_key(:plugin_missing_library)
+    end
+
+    class PluginMissingRubyDev < VagrantError
+      error_key(:plugin_missing_ruby_dev)
+    end
+
     class PluginGemNotFound < VagrantError
       error_key(:plugin_gem_not_found)
     end
@@ -1008,6 +1028,10 @@ module Vagrant
       error_key(:virtualbox_version_empty)
     end
 
+    class VirtualBoxInvalidHostSubnet < VagrantError
+      error_key(:virtualbox_invalid_host_subnet)
+    end
+
     class VMBaseMacNotSpecified < VagrantError
       error_key(:no_base_mac, "vagrant.actions.vm.match_mac")
     end
