@@ -12,6 +12,11 @@ module VagrantPlugins
       DESC
 
       command(:cloud) do
+        # Set this to match Vagant logging level so we get
+        # desired request/response information within the
+        # logger output
+        ENV["VAGRANT_CLOUD_LOG"] = Vagrant.log_level
+
         require_relative "root"
         init!
         Command::Root
@@ -22,6 +27,11 @@ module VagrantPlugins
         hook.prepend(AddAuthentication)
       end
 
+      action_hook(:cloud_authenticated_boxes, :authenticate_box_downloader) do |hook|
+        require_relative "auth/middleware/add_downloader_authentication"
+        hook.prepend(AddDownloaderAuthentication)
+      end
+
       protected
 
       def self.init!
