@@ -40,6 +40,11 @@ module VagrantPlugins
         require_relative "cap/rsync"
         Cap::RSync
       end
+
+      guest_capability(:redhat, :smb_install) do
+        require_relative "cap/smb"
+        Cap::SMB
+      end
     end
   end
 end
