@@ -16,6 +16,14 @@ module VagrantPlugins
       #
       # This handles all the `config.vm.network` configurations.
       class Network
+
+        # Location of the VirtualBox networks configuration file
+        VBOX_NET_CONF = "/etc/vbox/networks.conf".freeze
+        # Version of VirtualBox that introduced hostonly network range restrictions
+        HOSTONLY_VALIDATE_VERSION = Gem::Version.new("6.1.28")
+        # Default valid range for hostonly networks
+        HOSTONLY_DEFAULT_RANGE = [IPAddr.new("192.168.56.0/21").freeze].freeze
+
         include Vagrant::Util::NetworkIP
         include Vagrant::Util::ScopedHashOverride
 
@@ -256,8 +264,16 @@ module VagrantPlugins
           # Make sure the type is a symbol
           options[:type] = options[:type].to_sym
 
-          # Default IP is in the 20-bit private network block for DHCP based networks
-          options[:ip] = "172.28.128.1" if options[:type] == :dhcp && !options[:ip]
+          if options[:type] == :dhcp && !options[:ip]
+            # Try to find a matching device to set the config ip to
+            matching_device = hostonly_find_matching_network(options)
+            if matching_device
+              options[:ip] = matching_device[:ip]
+            else
+              # Default IP is in the 20-bit private network block for DHCP based networks
+              options[:ip] = "192.168.56.1"
+            end
+          end
 
           begin
             ip = IPAddr.new(options[:ip])
@@ -280,6 +296,8 @@ module VagrantPlugins
               error: e.message
           end
 
+          validate_hostonly_ip!(options[:ip], @env[:machine].provider.driver)
+
           if ip.ipv4?
             # Verify that a host-only network subnet would not collide
             # with a bridged networking interface.
@@ -469,7 +487,7 @@ module VagrantPlugins
 
         # This finds a matching host only network for the given configuration.
         def hostonly_find_matching_network(config)
-          this_netaddr = network_address(config[:ip], config[:netmask])
+          this_netaddr = network_address(config[:ip], config[:netmask])  if config[:ip]
 
           @env[:machine].provider.driver.read_host_only_interfaces.each do |interface|
             return interface if config[:name] && config[:name] == interface[:name]
@@ -493,6 +511,33 @@ module VagrantPlugins
           nil
         end
 
+        # Validates the IP used to configure the network is within the allowed
+        # ranges. It only validates if the network configuration file exists.
+        # This was introduced in 6.1.28 so previous version won't have restrictions
+        # placed on the valid ranges
+        def validate_hostonly_ip!(ip, driver)
+          return if Gem::Version.new(driver.version) < HOSTONLY_VALIDATE_VERSION ||
+            Vagrant::Util::Platform.windows?
+
+          ip = IPAddr.new(ip.to_s) if !ip.is_a?(IPAddr)
+          valid_ranges = load_net_conf
+          return if valid_ranges.any?{ |range| range.include?(ip) }
+          raise Vagrant::Errors::VirtualBoxInvalidHostSubnet,
+            address: ip,
+            ranges: valid_ranges.map{ |r| "#{r}/#{r.prefix}" }.join(", ")
+        end
+
+        def load_net_conf
+          return HOSTONLY_DEFAULT_RANGE if !File.exist?(VBOX_NET_CONF)
+          File.readlines(VBOX_NET_CONF).map do |line|
+            line = line.strip
+            next if !line.start_with?("*")
+            line[1,line.length].strip.split(" ").map do |entry|
+              IPAddr.new(entry)
+            end
+          end.flatten.compact
+        end
+
         #-----------------------------------------------------------------
         # DHCP Server Helper Functions
         #-----------------------------------------------------------------
@@ -515,7 +560,6 @@ module VagrantPlugins
         # @param [Hash<String>] config hash as returned from hostonly_config
         def create_dhcp_server_if_necessary(interface, config)
           existing_dhcp_server = find_matching_dhcp_server(interface)
-
           if existing_dhcp_server
             if dhcp_server_matches_config?(existing_dhcp_server, config)
               @logger.debug("DHCP server already properly configured")
