@@ -8,7 +8,7 @@ describe VagrantPlugins::HostBSD::Cap::NFS do
   describe ".nfs_export" do
     let(:environment) { double("environment", host: host) }
     let(:host) { double("host") }
-    let(:ui) { double("ui") }
+    let(:ui) { Vagrant::UI::Silent.new }
     let(:id) { "UUID" }
     let(:ips) { [] }
     let(:folders) { {} }
@@ -20,7 +20,6 @@ describe VagrantPlugins::HostBSD::Cap::NFS do
       allow(described_class).to receive(:nfs_cleanup)
       allow(described_class).to receive(:system)
       allow(File).to receive(:writable?).with("/etc/exports")
-      allow(ui).to receive(:info)
 
       allow(Vagrant::Util::Subprocess).to receive(:execute).with("nfsd", "checkexports").
         and_return(Vagrant::Util::Subprocess::Result.new(0, "", ""))
