@@ -5,7 +5,7 @@ require Vagrant.source_root.join("plugins/providers/hyperv/action/delete_vm")
 describe VagrantPlugins::HyperV::Action::DeleteVM do
   let(:app){ double("app") }
   let(:env){ {ui: ui, machine: machine} }
-  let(:ui){ double("ui") }
+  let(:ui){ Vagrant::UI::Silent.new }
   let(:provider){ double("provider", driver: driver) }
   let(:driver){ double("driver") }
   let(:machine){ double("machine", provider: provider, data_dir: "/dev/null") }
@@ -13,7 +13,6 @@ describe VagrantPlugins::HyperV::Action::DeleteVM do
 
   before do
     allow(app).to receive(:call)
-    allow(ui).to receive(:info)
     allow(driver).to receive(:delete_vm)
     allow(FileUtils).to receive(:rm_rf)
     allow(FileUtils).to receive(:mkdir_p)
