@@ -255,21 +255,6 @@ describe Vagrant::Action::Builder do
       subject.call(data)
 
       expect(data[:data]).to eq([1, 2])
-      expect(data[:action_hooks_already_ran]).to eq(true)
-    end
-
-    it "applies without prepend/append if it has already" do
-      hook_proc = proc{ |h| h.append(appender_proc(2)) }
-      expect(manager).to receive(:action_hooks).with(:test_action).
-        and_return([hook_proc])
-
-      data[:action_name] = :test_action
-
-      subject.use appender_proc(1)
-      subject.call(data.merge(action_hooks_already_ran: true))
-
-      expect(data[:data]).to eq([1])
-      subject.call(data)
     end
   end
 
@@ -365,6 +350,65 @@ describe Vagrant::Action::Builder do
       expect(data[:data].last).to eq(2)
     end
 
+    context "when hook matches action in subsequent builder" do
+      let(:hook_action_name) { ActionOne }
+
+      before do
+        data[:action_name] = :test_action_name
+        data[:raw_action_name] = :machine_test_action_name
+      end
+
+      it "should execute the hook" do
+        described_class.build(ActionTwo).call(data)
+        described_class.build(ActionOne).call(data)
+        expect(data[:data]).to include(:first)
+      end
+    end
+
+    context "when hook matches action name in subsequent builder" do
+      let(:hook_action_name) { :test_action_name }
+
+      before do
+        data[:action_name] = :test_action_name
+        data[:raw_action_name] = :machine_test_action_name
+      end
+
+      it "should execute the hook" do
+        described_class.build(ActionTwo).call(data)
+        described_class.build(ActionOne).call(data)
+        expect(data[:data]).to include(:first)
+      end
+
+      it "should execute the hook multiple times" do
+        described_class.build(ActionTwo).call(data)
+        described_class.build(ActionOne).call(data)
+        expect(data[:data].count{|d| d == :first}).to eq(2)
+      end
+    end
+
+    context "when applying triggers" do
+      let(:triggers) { double("triggers") }
+
+      before do
+        data[:action_name] = :test_action_name
+        data[:raw_action_name] = :machine_test_action_name
+        data[:triggers] = triggers
+        allow(triggers).to receive(:find).and_return([])
+      end
+
+      it "should attempt to find triggers based on raw action" do
+        expect(triggers).to receive(:find).with(data[:raw_action_name], any_args).and_return([])
+        described_class.build(ActionOne).call(data)
+      end
+
+      it "should only attempt to find triggers based on raw action once" do
+        expect(triggers).to receive(:find).with(data[:raw_action_name], :before, any_args).once.and_return([])
+        expect(triggers).to receive(:find).with(data[:raw_action_name], :after, any_args).once.and_return([])
+        described_class.build(ActionOne).call(data)
+        described_class.build(ActionOne).call(data)
+      end
+    end
+
     context "when hook is appending to action" do
       let(:plugin) do
         @plugin ||= Class.new(Vagrant.plugin("2")) do
@@ -549,12 +593,12 @@ describe Vagrant::Action::Builder do
 
             it "should add trigger action to start of stack" do
               subject.apply_dynamic_updates(env)
-              expect(subject.stack[0].first).to eq(Vagrant::Action::Builtin::Trigger)
+              expect(subject.stack[0].middleware).to eq(Vagrant::Action::Builtin::Trigger)
             end
 
             it "should have timing and type arguments" do
               subject.apply_dynamic_updates(env)
-              args = subject.stack[0][1]
+              args = subject.stack[0].arguments.parameters
               expect(args).to include(type)
               expect(args).to include(timing)
               expect(args).to include(action.to_s)
@@ -566,12 +610,12 @@ describe Vagrant::Action::Builder do
 
             it "should add trigger action to middle of stack" do
               subject.apply_dynamic_updates(env)
-              expect(subject.stack[1].first).to eq(Vagrant::Action::Builtin::Trigger)
+              expect(subject.stack[1].middleware).to eq(Vagrant::Action::Builtin::Trigger)
             end
 
             it "should have timing and type arguments" do
               subject.apply_dynamic_updates(env)
-              args = subject.stack[1][1]
+              args = subject.stack[1].arguments.parameters
               expect(args).to include(type)
               expect(args).to include(timing)
               expect(args).to include(action.to_s)
@@ -587,12 +631,12 @@ describe Vagrant::Action::Builder do
 
             it "should add trigger action to start of stack" do
               subject.apply_dynamic_updates(env)
-              expect(subject.stack[0].first).to eq(Vagrant::Action::Builtin::Trigger)
+              expect(subject.stack[0].middleware).to eq(Vagrant::Action::Builtin::Trigger)
             end
 
             it "should have timing and type arguments" do
               subject.apply_dynamic_updates(env)
-              args = subject.stack[0][1]
+              args = subject.stack[0].arguments.parameters
               expect(args).to include(type)
               expect(args).to include(timing)
               expect(args).to include(action.to_s)
@@ -609,7 +653,7 @@ describe Vagrant::Action::Builder do
 
             it "should have timing and type arguments" do
               subject.apply_dynamic_updates(env)
-              args = subject.stack[1][1]
+              args = subject.stack[1].arguments.parameters
               expect(args).to include(type)
               expect(args).to include(timing)
               expect(args).to include(action.to_s)
@@ -637,11 +681,6 @@ describe Vagrant::Action::Builder do
     before { allow(triggers).to receive(:find).and_return([]) }
     after { @subject = nil }
 
-    it "should mark action hooks applied within env" do
-      subject.apply_action_name(env)
-      expect(env[:action_hooks_already_ran]).to be_truthy
-    end
-
     context "when a plugin has added an action hook" do
       let(:plugin) do
         @plugin ||= Class.new(Vagrant.plugin("2")) do
@@ -663,18 +702,11 @@ describe Vagrant::Action::Builder do
         subject.apply_action_name(env)
         expect(subject.stack[0].first).to eq(Vagrant::Action::Builtin::Call)
       end
-
-      it "should only add new action to the call stack once" do
-        subject.apply_action_name(env)
-        subject.apply_action_name(env)
-        expect(subject.stack[0].first).to eq(Vagrant::Action::Builtin::Call)
-        expect(subject.stack[1].first).not_to eq(Vagrant::Action::Builtin::Call)
-      end
     end
 
     context "when trigger has been defined for raw action" do
       before do
-        expect(triggers).to receive(:find).with(raw_action_name, timing, nil, :action).
+        expect(triggers).to receive(:find).with(raw_action_name, timing, nil, :action, all: true).
           and_return([true])
       end
 
@@ -688,7 +720,7 @@ describe Vagrant::Action::Builder do
 
         it "should include arguments to the trigger action" do
           subject.apply_action_name(env)
-          args = subject.stack[0][1]
+          args = subject.stack[0].arguments.parameters
           expect(args).to include(raw_action_name)
           expect(args).to include(timing)
           expect(args).to include(:action)
@@ -705,9 +737,9 @@ describe Vagrant::Action::Builder do
 
         it "should include arguments to the trigger action" do
           subject.apply_action_name(env)
-          builder = subject.stack.first[1]&.first
+          builder = subject.stack.first.arguments.parameters.first
           expect(builder).not_to be_nil
-          args = builder.stack.first[1]
+          args = builder.stack.first.arguments.parameters
           expect(args).to include(raw_action_name)
           expect(args).to include(timing)
           expect(args).to include(:action)
@@ -728,12 +760,12 @@ describe Vagrant::Action::Builder do
 
         it "should add a trigger action to the start of the stack" do
           subject.apply_action_name(env)
-          expect(subject.stack[0].first).to eq(Vagrant::Action::Builtin::Trigger)
+          expect(subject.stack[0].middleware).to eq(Vagrant::Action::Builtin::Trigger)
         end
 
         it "should include arguments to the trigger action" do
           subject.apply_action_name(env)
-          args = subject.stack[0][1]
+          args = subject.stack[0].arguments.parameters
           expect(args).to include(action_name)
           expect(args).to include(timing)
           expect(args).to include(:hook)
@@ -750,7 +782,7 @@ describe Vagrant::Action::Builder do
 
         it "should include arguments to the trigger action" do
           subject.apply_action_name(env)
-          args = subject.stack.last[1]
+          args = subject.stack.last.arguments.parameters
           expect(args).to include(action_name)
           expect(args).to include(timing)
           expect(args).to include(:hook)
